@@ -27,6 +27,8 @@
 #' @param chains number of chains to sample, during HMC or post-optimization importance sampling.
 #' @param verbose integer from 0 to 2. Higher values print more information during model fit – for debugging
 #' @param customPar logical. If set TRUE (default) leverages the first pass using priors and ensure that the drift diagonal cannot easily go too negative (helps since ctsem > 3.4)
+#' @param scaleTime scale time (interval) - sometimes desirable to improve fitting
+
 #'
 #' @importFrom RPushbullet pbPost
 #' @importFrom crayon red blue
@@ -87,7 +89,8 @@ ctmaPower <- function(
   iter=NULL,
   chains=NULL,
   verbose=NULL,
-  customPar=TRUE
+  customPar=FALSE,
+  scaleTime=NULL
 )
 
 {  # begin function definition (until end of file)
@@ -95,6 +98,14 @@ ctmaPower <- function(
   { ### CHECKS
 
     { # fitting params
+
+      # Added 10. Oct 2022 (17. Aug 2022 in Init fit similar)
+      tmp1 <- names(CoTiMA::CoTiMAStanctArgs) %in% names(CoTiMAStanctArgs); tmp1
+      tmp2 <- CoTiMA::CoTiMAStanctArgs
+      if (!(is.null(CoTiMAStanctArgs))) tmp2[tmp1] <- CoTiMAStanctArgs
+      CoTiMAStanctArgs <- tmp2
+
+      if (!(is.null(scaleTime))) CoTiMAStanctArgs$scaleTime <- scaleTime
       if (!(is.null(optimize))) CoTiMAStanctArgs$optimize <- optimize
       if (!(is.null(nopriors))) CoTiMAStanctArgs$nopriors <- nopriors
       if (!(is.null(finishsamples))) CoTiMAStanctArgs$optimcontrol$finishsamples <- finishsamples
@@ -628,7 +639,7 @@ ctmaPower <- function(
       #
     }
   }
-  pValues
+  #pValues
 
   Msg <- "################################################################################# \n# Compute min and max discrete time intervals for which effects are significant # \n#################################################################################"
   message(Msg)
@@ -892,7 +903,9 @@ ctmaPower <- function(
   minN <- (apply(requiredSampleSizes, 2, min, na.rm=TRUE)); minN
   optimalCrossLagN <- c()
   for (h in 1:(dim(requiredSampleSizes)[2])) optimalCrossLagN[h] <- mean(which(requiredSampleSizes[ ,h ] == minN[h]))
-  optimalCrossLagN <- optimalCrossLagN*stepWidth; optimalCrossLagN
+  # CHD next line replace by line below 10. OCT 2022
+  #optimalCrossLagN <- optimalCrossLagN*stepWidth; optimalCrossLagN
+  optimalCrossLagN <- as.numeric(rownames(requiredSampleSizes))[round(optimalCrossLagN-.4, 0)]
   requiredSampleSizes <- rbind(requiredSampleSizes, minN, optimalCrossLagN)
   rownames(requiredSampleSizes) <- rowNames
   tmp1 <- grep("Power", colnames(requiredSampleSizes)); tmp1
